@@ -32,7 +32,8 @@ def set_task_id(id : str) -> None:
     task_id = id
 
 def set_logging_target(key: str) -> None:
-    {'element_key' : 'Logs'}
+    global logging_target
+    logging_target = {'element_key' : key}
 
 # edit one of the elements in the task, this allows data updating
 def edit_element(element_uid : str, value : Any) -> None:
